@@ -11,7 +11,7 @@ const (
 type Pager struct {
 	Page         int    `json:"page" form:"page" query:"page" url:"page" binding:"gte=1"`                              // 页码
 	PageSize     int    `json:"page_size" form:"page_size" query:"page_size" url:"page_size" binding:"gte=10,lte=100"` // 每页数量
-	Order        int    `json:"-" form:"order" query:"page" binding:"oneof=0 1 2 3"`                                   // 已定义字段排序 0 ID顺序 1 ID倒序
+	Order        int    `json:"-" form:"order" query:"order" url:"order" binding:"oneof=0 1 2 3"`                      // 已定义字段排序 0 ID顺序 1 ID倒序
 	OrderByField string `json:"-" form:"order_by_field" query:"order_by_field" url:"order_by_field"`                   // 自定义字段排序
 	TotalRows    int64  `json:"total_rows"`                                                                            // 总行数
 }
